MissionMinder = MissionMinder or {};

local addon = MissionMinder;
addon.name = "MissionMinder"; --internal name; purposefully non-localized
addon.version = GetAddOnMetadata(addon.name, "Version");
addon.options = {};
local options = addon.options;

local L = LibStub("AceLocale-3.0"):GetLocale("MissionMinder");

function MissionMinder.debug(format, ...)

end

local DEBUG = MissionMinder.debug;

---------------------------------------------
-- OPTIONS
---------------------------------------------

local AUTO_OPEN_REWARDS = "AutoOpenRewards";
local AUTO_CLOSE = "AutoClose";
local SKIP_FIGHT_ANIMATIONS = "SkipFightAnimations";
local QUICK_LOOT = "QuickLoot";


MissionMinderOptions = {};
local MissionMinderOptions_DEFAULT = {
	[AUTO_OPEN_REWARDS] = false,
	[AUTO_CLOSE] = false,
	[SKIP_FIGHT_ANIMATIONS] = false,
	[QUICK_LOOT] = false
};

function options.AutoLootRewards()
	return MissionMinderOptions[AUTO_OPEN_REWARDS];
end

function options.AutoClose()
	return MissionMinderOptions[AUTO_CLOSE];
end

function options.SkipFightAnimations()
	return MissionMinderOptions[SKIP_FIGHT_ANIMATIONS];
end

function options.QuickLoot()
	return MissionMinderOptions[QUICK_LOOT];
end


---------------------------------------------
-- OPTIONS PANE
---------------------------------------------

local config = LibStub("AceConfig-3.0")
local dialog = LibStub("AceConfigDialog-3.0")

local function createOptions()
	local function getValue(info)
		return MissionMinderOptions[info.arg];
	end

	local function setValue(info, value)
		MissionMinderOptions[info.arg] = value;
	end

	local options = {
		name = L["MissionMinder"] .. " " .. addon.version,
		desc = L["Manage garrison missions in a more streamline, less-invasive manner"],
		type = "group",
		args = {
			desc = {
				order = 2,
				type = "description",
				name = L["Manage garrison missions in a more streamline, less-invasive manner"],
				width = "full"
			},
			emptySpace = {
				order = 3,
				type = "description",
				name = " ",
				width = "full"
			},
			listview = {
				order = 10,
				type = "group",
				inline = true,
				name = L["List View"],
				args = {
					description = {
						order = 1,
						type = "description",
						name = L["View completed missions as a list from the \"In Progress\" tab"],
						width = "full",
					},
					spacer = {
						order = 2,
						type = "description",
						name = " ",
						width = "full",
					},
					quickLoot = {
						order = 25,
						name = L["Quick loot"],
						desc = L["Disable the completion frame entirely, skip all the fanfare, and just give me the loot already!"],
						type = "toggle",
						width = "double",
						set = setValue,
						get = getValue,
						arg = QUICK_LOOT
					}
				}
			},
			general = {
				order = 15,
				type = "group",
				inline = true,
				disabled = function() return options.QuickLoot(); end,
				name = L["General Options"],
				args = {
					skipFightAnimations = {
						order = 5,
						name = L["Skip fight animations"],
						desc = L["Skip all fight animations and go straight to rewards"],
						type = "toggle",
						width = "double",
						set = setValue,
						get = getValue,
						arg = SKIP_FIGHT_ANIMATIONS
					},
					autoOpenRewards = {
						order = 10,
						name = L["Automatically open rewards chest"],
						desc = L["Remove the need to click on the rewards chest to recieve the rewards"],
						type = "toggle",
						width = "double",
						set = setValue,
						get = getValue,
						arg = AUTO_OPEN_REWARDS
					},
					autoClose = {
						order = 15,
						name = L["Automatically close on loot"],
						desc = L["Automatically close the completion dialog if all actions have been completed for a mission"],
						type = "toggle",
						width = "double",
						set = setValue,
						get = getValue,
						arg = AUTO_CLOSE
					}
				}
			}
		}
	};

	config:RegisterOptionsTable("MissionMinderOptions", options);
	return dialog:AddToBlizOptions("MissionMinderOptions", L["MissionMinder"]);
end


local frame = createOptions();
addon.options.frame = frame;


function frame.OnEvent(self, event, arg1)
	if event == "ADDON_LOADED" and arg1 == addon.name then
		frame:UnregisterEvent("ADDON_LOADED");

		-- SavedVariables have been loaded, rewrite to include any new or missing values
		for key,value in pairs(MissionMinderOptions_DEFAULT) do
			if MissionMinderOptions[key] == nil then
				MissionMinderOptions[key] = value;
			end
		end

		-- Rewrite to remove any deprecated settings
		for key,value in pairs(MissionMinderOptions) do
			if MissionMinderOptions_DEFAULT[key] == nil then
				MissionMinderOptions[key] = nil;
			end
		end
 	end
end
frame:SetScript("OnEvent", frame.OnEvent);
frame:RegisterEvent("ADDON_LOADED");
