local L = LibStub("AceLocale-3.0"):GetLocale("MissionMinder");
local OPTIONS = MissionMinder.options;
local DEBUG = MissionMinder.debug;

MissionMinder.quickloot = {};
local addon = MissionMinder.quickloot;

function addon.initialize()
end

local function createInlineTexture(texture)
	return texture and ("|T" .. texture .. ":0|t") or nil;
end

local function getRewards(missionID)
		local rewards = C_Garrison.GetMissionRewardInfo(missionID);
		local str = {};

		for _, reward in pairs(rewards) do
			if(reward.followerXP) then
				local xp = reward.followerXP;
				if ( xp >= 1000 ) then
					xp = xp/1000 .. L["K"];
				end
				tinsert(str, "+" .. xp .. " " .. createInlineTexture(reward.icon));
			elseif (reward.itemID) then
				local _, link = GetItemInfo(reward.itemID);
				if(reward.quantity == 1) then
					tinsert(str, link);
				else
					tinsert(str, reward.quantity .. "x " .. link);
				end
			elseif(reward.currencyID) then
				if (reward.currencyID == 0) then -- gold
					tinsert(str, GetCoinTextureString(reward.quantity));
				else
					tinsert(str, reward.quantity .. " " .. createInlineTexture(reward.icon));
				end
			else
				tinsert(str, reward.title);
			end
		end

		return table.concat(str, ", ");
end


local events = MissionMinder.events;
events:RegisterEvent("GARRISON_MISSION_COMPLETE_RESPONSE", function(event, missionID, canComplete, succeeded)
	if ( OPTIONS.QuickLoot() ) then
		local missionLink = C_Garrison.GetMissionLink(missionID);
		if ( succeeded ) then
			local rewards = getRewards(missionID);
			SendSystemMessage(string.format(L["Mission %s was successful! Received %s"], missionLink, rewards));
		else
			SendSystemMessage(string.format(L["Mission %s failed!"], missionLink));
		end

		if ( C_Garrison.CanOpenMissionChest(missionID)) then
			C_Garrison.MissionBonusRoll(missionID);
		end
	end
end);

events:RegisterEvent("GARRISON_FOLLOWER_XP_CHANGED", function(event, followerID, xpAward, oldXP, oldLevel, oldQuality)
	local follower =  C_Garrison.GetFollowerInfo(followerID);
	local followerLink = C_Garrison.GetFollowerLink(follower.followerID) or follower.name;
	local maxXP = GarrisonMissionFrame_GetFollowerNextLevelXP(oldLevel, oldQuality);

	if ( maxXP ) then  -- nil if already maxLevel and maxQuality
		if ( xpAward + oldXP >= maxXP ) then -- level up
			if ( oldLevel < GarrisonMissionFrame.followerMaxLevel ) then
				SendSystemMessage(string.format(L["Follower %s has reached level %d!"], followerLink, oldLevel + 1));
			elseif ( oldQuality < GarrisonMissionFrame.followerMaxQuality ) then
				SendSystemMessage(string.format(L["Follower %s has reached %s quality!"], followerLink, getglobal("ITEM_QUALITY" .. oldQuality + 1 .. "_DESC")));
			end
		end
	end
end);
